Roll recipe dependencies (trivial).

This is an automated CL created by the recipe roller. This CL rolls
recipe changes from upstream projects (chromiumos_config, recipe_engine) into this repository.

chromiumos_config:
https://chromium.googlesource.com/chromiumos/config.git/+log/cc7759992171f4ea6a6ad33d643113b231347d9d~..7cc622dad0e8a1e477511009339e63fda4830490
  cc77599 (smcallis@google.com)
      Be more permissive with HWID format for cameras.
  901f041 (smcallis@google.com)
      Merge in touchscreen information.
  b276701 (smcallis@google.com)
      Recognize vendor: ATA as a SATA drive
  68832c8 (evgreen@chromium.org)
      partner.star: Fix raydium firmware file paths
  7cc622d (smcallis@google.com)
      Merge in stylus information to backfill.

recipe_engine:
https://chromium.googlesource.com/infra/luci/recipes-py.git/+/86c55e698c80adc9d26af56e398081d8cb773464
  86c55e6 (bryner@google.com)
      Explicitly run python2 from recipes.py.

More info is at https://goo.gl/zkKdpD. Use https://goo.gl/noib3a to file a bug.

R=seanabraham@chromium.org

Recipe-Tryjob-Bypass-Reason: Autoroller
Bugdroid-Send-Email: False
Change-Id: Ie1957a925a1d653be19c97bb173f0c7e2887eb18
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/infra/proto/+/2774134
Commit-Queue: Recipe Roller <recipe-mega-autoroller@chops-service-accounts.iam.gserviceaccount.com>
Bot-Commit: Recipe Roller <recipe-mega-autoroller@chops-service-accounts.iam.gserviceaccount.com>
diff --git a/infra/config/recipes.cfg b/infra/config/recipes.cfg
index cf17321..c272d10 100644
--- a/infra/config/recipes.cfg
+++ b/infra/config/recipes.cfg
@@ -16,12 +16,12 @@
   "deps": {
     "chromiumos_config": {
       "branch": "refs/heads/main",
-      "revision": "135cde9ed1a4d713ec3f2c7d3225110d914510fa",
+      "revision": "a4579cbba47534cb1936533aea03f86e5a0b15b8",
       "url": "https://chromium.googlesource.com/chromiumos/config.git"
     },
     "recipe_engine": {
       "branch": "refs/heads/master",
-      "revision": "c6627c1d2201fd582e7ca4b777c4749798d6c4db",
+      "revision": "86c55e698c80adc9d26af56e398081d8cb773464",
       "url": "https://chromium.googlesource.com/infra/luci/recipes-py.git"
     }
   },
diff --git a/recipes/recipes.py b/recipes/recipes.py
index 4339ba3..9804a4c 100755
--- a/recipes/recipes.py
+++ b/recipes/recipes.py
@@ -6,12 +6,12 @@
 # We want to run python in unbuffered mode; however shebangs on linux grab the
 # entire rest of the shebang line as a single argument, leading to errors like:
 #
 #   /usr/bin/env: 'python -u': No such file or directory
 #
 # This little shell hack is a triple-quoted noop in python, but in sh it
 # evaluates to re-exec'ing this script in unbuffered mode.
 # pylint: disable=pointless-string-statement
-''''exec python -u -- "$0" ${1+"$@"} # '''
+''''exec python2 -u -- "$0" ${1+"$@"} # '''
 # vi: syntax=python
 """Bootstrap script to clone and forward to the recipe engine tool.
@@ -6,12 +6,12 @@
 # entire rest of the shebang line as a single argument, leading to errors like:
 #
-#   /usr/bin/env: 'python -u': No such file or directory
+#   /usr/bin/env: 'python2 -u': No such file or directory
 #
 # This little shell hack is a triple-quoted noop in python, but in sh it